@@ -18,10 +18,12 @@ parser.add_argument('-c','--context',help='The showdown set meta to use (2000-20
 parser.add_argument('-o','--offset',help='Get alternate chart n away from most accurate',default=0)
 parser.add_argument('-url','--image_url',help='URL link to Player background image',default=None)
 parser.add_argument('-path','--image_path',help='Path to Player background image on local machine',default=None)
+parser.add_argument('-o_path','--image_output_path',help='Path to folder for card image output',default='')
 parser.add_argument('-num','--set_num',help='Assign card a set number',default='001')
 parser.add_argument('-show','--show_image', action='store_true', help='Optionally open the final Player Card Image upon completion')
 parser.add_argument('-cc','--is_cc', action='store_true', help='Optionally make the card Cooperstown Collection')
 parser.add_argument('-ss','--is_ss', action='store_true', help='Optionally make the card Super Season')
+parser.add_argument('-asg','--is_asg', action='store_true', help='Optionally make the card All Star Game')
 parser.add_argument('-co','--co_override',help='Manually select a command/out combination',default='', type=str)
 parser.add_argument('-exp','--expansion',help='Add optional expansion logo (ex: TD, PR)',default='BS')
 args = parser.parse_args()
@@ -43,11 +45,13 @@ def main():
         stats=statline,
         is_cooperstown=args.is_cc,
         is_super_season=args.is_ss,
+        is_all_star_game=args.is_asg,
         context=args.context,
         expansion=args.expansion,
         offset=args.offset,
         player_image_url=args.image_url,
         player_image_path=args.image_path,
+        card_img_output_folder_path=args.image_output_path,
         print_to_cli=True,
         show_player_card_image=args.show_image,
         set_number=str(args.set_num),
